@@ -18,32 +18,23 @@
 
 #include "contactnotify.h"
 
-#include <KDebug>
+#include <KTp/core.h>
+#include <KTp/presence.h>
+#include <KTp/global-contact-manager.h>
 
 #include <TelepathyQt/ContactManager>
 #include <TelepathyQt/AccountManager>
 #include <TelepathyQt/Contact>
 
-#include <KNotification>
 #include <KAboutData>
 #include <KConfigGroup>
+#include <KDebug>
+#include <KNotification>
 
-#include <KTp/presence.h>
-#include <KTp/global-contact-manager.h>
-
-using namespace KTp;
-
-ContactNotify::ContactNotify(const Tp::AccountManagerPtr &accountMgr, QObject *parent) :
+ContactNotify::ContactNotify(QObject *parent) :
     QObject(parent)
 {
-    Q_ASSERT(accountMgr);
-    m_accountManager = accountMgr;
-    if (!m_accountManager) {
-        return;
-    }
-
-    GlobalContactManager *contactManager = new GlobalContactManager(m_accountManager, this);
-
+    KTp::GlobalContactManager *contactManager = KTp::contactManager();
     Tp::Presence currentPresence;
 
     Q_FOREACH(const Tp::ContactPtr &contact, contactManager->allKnownContacts()) {
@@ -51,7 +42,7 @@ ContactNotify::ContactNotify(const Tp::AccountManagerPtr &accountMgr, QObject *p
                 SLOT(contactPresenceChanged(Tp::Presence)));
 
         currentPresence = contact->presence();
-        m_presenceHash[contact->id()] = Presence::sortPriority(currentPresence.type());
+        m_presenceHash[contact->id()] = KTp::Presence::sortPriority(currentPresence.type());
     }
 
     connect(contactManager, SIGNAL(allKnownContactsChanged(Tp::Contacts,Tp::Contacts)),
@@ -62,7 +53,7 @@ ContactNotify::ContactNotify(const Tp::AccountManagerPtr &accountMgr, QObject *p
 void ContactNotify::contactPresenceChanged(const Tp::Presence &presence)
 {
     KTp::Presence ktpPresence(presence);
-    Tp::ContactPtr contact(qobject_cast<Tp::Contact*>(QObject::sender()));
+    KTp::ContactPtr contact(qobject_cast<KTp::Contact*>(QObject::sender()));
     int priority = m_presenceHash[contact->id()];
 
     // Don't show presence messages when moving from a higher priority to a lower
@@ -74,14 +65,14 @@ void ContactNotify::contactPresenceChanged(const Tp::Presence &presence)
                                "%1 is now %2",
                                contact->alias(),
                                ktpPresence.displayString()),
-                         ktpPresence.icon(),
+                         contact->avatarPixmap(),
                          contact);
     }
 
-    m_presenceHash.insert(contact->id(), Presence::sortPriority(presence.type()));
+    m_presenceHash.insert(contact->id(), KTp::Presence::sortPriority(presence.type()));
 }
 
-void ContactNotify::sendNotification(const QString &text, const KIcon &icon, const Tp::ContactPtr &contact)
+void ContactNotify::sendNotification(const QString &text, const QPixmap &pixmap, const Tp::ContactPtr &contact)
 {
     //The pointer is automatically deleted when the event is closed
     KNotification *notification;
@@ -90,7 +81,7 @@ void ContactNotify::sendNotification(const QString &text, const KIcon &icon, con
     KAboutData aboutData("ktelepathy", 0, KLocalizedString(), 0);
     notification->setComponentData(KComponentData(aboutData));
 
-    notification->setPixmap(icon.pixmap(48));
+    notification->setPixmap(pixmap);
     notification->setText(text);
     notification->addContext(QLatin1String("contact"), contact.data()->id());
     notification->sendEvent();
@@ -107,7 +98,7 @@ void ContactNotify::onContactsChanged(const Tp::Contacts &contactsAdded, const T
                 SLOT(contactAvatarTokenChanged(QString)));
 
         currentPresence = contact->presence();
-        m_presenceHash[contact->id()] = Presence::sortPriority(currentPresence.type());
+        m_presenceHash[contact->id()] = KTp::Presence::sortPriority(currentPresence.type());
 
     }
 
