@@ -55,17 +55,21 @@ Q_SIGNALS:
     void settingsChanged();
 
 private Q_SLOTS:
-    void onAccountManagerReady(Tp::PendingOperation*);
+    void onAccountManagerReady(Tp::PendingOperation *op);
     void onRequestedPresenceChanged(const KTp::Presence &presence);
     void onPluginActivated(bool);
 
 private:
     /** Returns the presence we think we should be in. Either from the highest priority plugin, or if none are active, the last user set.*/
     KTp::Presence currentPluginPresence() const;
+    QString currentPluginStatusMessage();
+    KTp::Presence presenceThrottle();
+    const QString statusMessageStack();
+    bool activePlugin();
+    bool activeStatusMessagePlugin();
     void setPresence(const KTp::Presence &presence);
 
 private:
-    Tp::AccountManagerPtr    m_accountManager;
     AutoAway                *m_autoAway;
     TelepathyMPRIS          *m_mpris;
     AutoConnect             *m_autoConnect;
@@ -76,6 +80,7 @@ private:
     ScreenSaverAway         *m_screenSaverAway;
 
     QList<TelepathyKDEDModulePlugin*> m_pluginStack;
+    QList<TelepathyKDEDModulePlugin*> m_statusMessagePluginStack;
     KTp::Presence m_lastUserPresence;
 };
 
